export interface IOptions {
    documentPath?: string;
    outputPath?: string;
    tempPath?: string;
    layout?: string;
    language?: string;
    writeMetadata?: boolean;
    document?: IDocumentInformation;
    pdf?: IPdfOptions;
    useHtml?: boolean;
}
export interface IPdfOptions {
    wkhtmltopdfPath?: string;
    pdfRenderTimeout?: number;
    marginBottom?: number;
    marginLeft?: number;
    marginRight?: number;
    marginTop?: number;
    orientation?: 'Landscape' | 'Portrait';
    pageSize?: string;
    pageHeight?: number;
    pageWidth?: number;
    zoom?: number;
    header?: IPdfHeaderFooterOptions;
    footer?: IPdfHeaderFooterOptions;
    parts?: {
        [key: string]: IPdfPart;
    };
}
export interface IPdfHeaderFooterOptions {
    html?: string;
    spacing?: number;
    data?: any;
}
export interface IPdfPart {
    type?: 'cover' | 'toc' | 'content';
    html?: string;
    data?: any;
}
export interface IPdfCoverPart extends IPdfPart {
}
export interface IPdfTocPart extends IPdfPart {
    xslStyleSheet?: string;
}
export interface IPdfContentPart extends IPdfPart {
}
export interface IDocumentInformation {
    title?: string;
    subject?: string;
    authors?: string[];
    keywords?: string[];
    date?: string;
    data?: any;
}
export declare class OptionsService {
    private readonly OPTIONS_FILE;
    private readonly OPTIONS_EXT;
    consolidateAsync(options: IOptions): Promise<void>;
    private fallbackOptionsToDocument(options);
    private getAndCheckLayoutExistanceAsync(options);
    private fallbackOptionsToLayout(options);
    private fallbackOptionsToDefault(options);
    private loadOptionsByFile(file);
    private applyFallbackOptions(options, fallback);
}
declare const _default: OptionsService;
export default _default;
